# Rossari Science Translational Medicine 2025 #

Rossari F, Alvisi G, Cusimano M, Beretta S, et al.
**A Private Crosstalk Established by Tumor-Targeted Cytokine Release Rescues CAR-T Activity and Engages Host T Cells against Glioblastoma.**
2025.

GEO: [GSE259346](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE259346)

---

## Directories ##
- **Clustering_analysis**: folder containing the script used for the clustering analysis.
- **MultiNicheNet**: folder containing the script used for the cell-cell interaction analysis.
- **ProjectTILs**: folder containing the script used for the T cell state identification analysis.
- **SCENIC_CART**: folder containing the script used for the gene regulatory network analysis.
- **WPRE_mapping**: folder containing the script used for the WPRE sequence mapping analysis.

---

## Analyses ##

Single-cell (from 10X Genomics) analysis of 12 mouse samples from 4 different conditions (n=3 per group).

#### Clustering Analysis ####
Demultiplexing of the input Fastq files was done using the _CellRanger_ v7.2.0 software (10X Genomics), followed by the aliment of the resulting input reads against the _mm10_ mouse reference genome (Ensembl 93), and the UMI quantification to produce a cell-by-gene count table for each sample.</br>
These input matrices were then imported into the _R_ environment (v. 4.3.2) and analysed with _Seurat_ v5.0.1. Cells expressing less than 500 (which suggest false identified cells or low viability) or more than 6000 (which is an indicator of potential doublets) genes were filtered out. Cells having more than 10% of transcripts coming from mitochondrial genes, corresponding to dying cells, were also removed. After these initial steps, samples were combined into a single Seurat object keeping track of their original sample and group condition (i.e., Empty, IFN, oIL2, and IFN+oIL2).</br>
The resulting merged matrix was log-normalized with a scale factor of 1000 by using the _NormalizedData_ function of the Seurat package, and the most variable genes were identified with the “vst” selection method of the _FindVariableFeatures_ function. The _ScaleData_ function was used to scale the data based on the percentage of mitochondrial genes, the absolute count of RNAs in each cell, and the difference between S and G2/M cell cycle scores computed for each cell and, after that, 50 principal components (PCs) were computed for dimensionality reduction. To remove possible batch effects among conditions, the _Harmony_ method was applied to the data considering the sample identity as variable (batch) to remove, and a UMAP-representation as well as clusters were computed on those reductions. Marker genes for each cluster were obtained using the _FindAllMarkers_ function, and consequently clusters were annotated and manually curated.</br>
Subsets of cells belonging to T cells, TAMs and DCs were identified relying on the computed cluster markers, isolated, and re-analysed following the same procedure adopted for the merged dataset.

#### Cell-cell interaction analysis ####
To explore the interactions of CAR-Ts with TAMs and DCs we employed **MultiNicheNet**, a method for differential cell-cell communication analysis among conditions. More precisely, this technique is designed to handle multi-sample, multi-group single-cell data by looking at cell-cell communication between the cell types in each sample and compare the resulting patterns between groups of interest.</br>
As a first step we extracted abundance and expression information from sender (CAR-Ts) and receiver (TAMs and DCs) cell types combining this expression of ligands in the senders to the corresponding receptors in the receivers. A set of affected target genes in the receiver was defined based on genome-wide differential expression analysis of receiver and sender cell types and subsequently used to predict the NicheNet ligand activities and NicheNet ligand-target links. NicheNet ligand-target links were finally used to prioritize all sender/ligand-receiver/receptor pairs and calculate their expression correlation with the predicted target genes.

#### Interpretation of T cell states using reference atlas ####
To better characterize the composition of identified CAR-Ts, we adopted **ProjecTILs**, which is a computational method to project a single-cell dataset into a reference atlas to compare them without altering the structure of the reference one. Briefly, CAR-Ts from individual samples were independently mapped on the reference mouse TILs’ atlas; cluster composition was then assessed throughout treatment groups (i.e., Empty, IFN, oIL2, and IFN+oIL2).

#### Gene regulatory network analysis ####
To investigate CAR-T regulatory pathways activated by different treatments, we ran **SCENIC** which is a computational method to infer Gene Regulatory Networks (GRN) from scRNA-seq data.</br>
In details, starting from the UMI count matrix, the potential targets of the same transcription factor (TF) (gene regulatory networks) are identified based on co-expression using the GRNBoost algorithm and then potential direct-binding targets (regulons) are selected based on DNA-motif analysis (i.e., TF motif analysis). Finally, the network activity of regulons is computed in each individual cell and combined to obtain the average regulon activity by treatment group.

#### WPRE sequence mapping ####
To refine the identification of CAR-Ts, we created a modified mm10 reference genome, by adding the WPRE sequence as additional gene, and run the alignment and quantification steps with the CellRanger v7.2.0 software (10X Genomics) on it. To reduce the number of false negative errors due to possible biases in the WPRE expression and to strengthen its signal, we employed the Markov Affinity-based Graph Imputation of Cells (**MAGIC**) technique.</br>
More precisely, starting from the input matrices we run the imputation on the Cd8a, Cd4, Cd3e, Cd14, Mki67, Top2a, and WPRE genes. Then, based on the distribution of the resulting imputed expression values of the WPRE sequence, CAR-Ts were selected among those belonging to Cd8-expressing clusters and displaying either basal or imputed WPRE expression higher than 0.05.
